TypeLayout

Struct TypeLayout 

pub struct TypeLayout { /* private fields */ }
The layout of a type, also includes metadata about where the type was defined.

Implementations

Source

impl TypeLayout

pub const fn shared_vars(&self) -> &'static SharedVars

Gets the SharedVars of the type, containing the slices that many types inside TypeLayout contain ranges into.

pub fn package_and_version(&self) -> (RStr<'static>, VersionStrings)

Gets the package and package version where the type was declared.

pub fn package(&self) -> RStr<'static>

Gets the package where the type was declared.

pub fn package_version(&self) -> VersionStrings

Gets the package version for the package where the type was declared.

pub const fn line(&self) -> u32

Gets which line the type was defined in.

pub const fn mod_path(&self) -> ModPath

Gets the full path to the module where the type was defined.

pub fn extra_checks(&self) -> Option<ExtraChecksStaticRef>

Gets a trait object used to check extra properties about the type.

pub const fn get_fields(&self) -> Option<TLFields>

Gets the fields of the type.

Return value

If this a:

  • primitive or opaque type: It returns None.

  • enum: It returns Some() with all the fields in the order that they were declared, ignoring variants.

  • structs/unions/prefix types: It returns Some() with all the fields in the order that they were declared.

pub const fn is_prefix_kind(&self) -> bool

Whether this is a prefix-type(module or vtable).

pub fn name(&self) -> &'static str

Gets the name of the type.

pub const fn is_nonzero(&self) -> bool

Gets whether the type is a NonZero type, which can be put in an Option while being ffi-safe.

pub fn get_utypeid(&self) -> UTypeId

Gets the UTypeId for the type, which is an ffi safe equivalent of TypeId.

pub const fn item_info(&self) -> &ItemInfo

Gets information about where a type was declared.

pub const fn alignment(&self) -> usize

Gets the alignment of the type.

pub const fn size(&self) -> usize

Gets the size of the type.

pub const fn tag(&self) -> &'static Tag

Gets the Tag associated with a type, a JSON-like datastructure which is another way to check extra properties about a type.

pub const fn repr_attr(&self) -> ReprAttr

Gets the representation attribute of the type.

pub const fn mod_refl_mode(&self) -> ModReflMode

Gets the ModReflMode for the type, whether this is a module whose definition can be reflected on at runtime.

pub fn data(&self) -> TLData

The interior of the type definition, describing whether the type is a primitive/enum/struct/union and its contents.

pub const fn data_discriminant(&self) -> TLDataDiscriminant

Describes whether the type is a primitive/enum/struct/union, every variant corresponds to a TLData variant of the same name.

pub fn phantom_fields(&self) -> TLFields

Gets the virtual fields that aren’t part of th type definition, but are checked as part of the type

pub fn generics(&self) -> GenericParams

Gets the generic parameters of the type.

pub const fn mono_type_layout(&self) -> &MonoTypeLayout

Gets the parts of the type layout that don’t change with generic parameters.